package org.example.palabres.webapp.action;

import java.util.List;
import java.util.Map;

import org.apache.commons.lang3.StringUtils;
import org.apache.struts2.interceptor.SessionAware;
import com.opensymphony.xwork2.ActionSupport;

import org.example.palabres.model.bean.chat.Channel;
import org.example.palabres.model.bean.chat.Message;
import org.example.palabres.model.exception.FunctionalException;
import org.example.palabres.model.exception.NotFoundException;
import org.example.palabres.model.exception.TechnicalException;
import org.example.palabres.webapp.WebappHelper;


/**
 * Action gérant le chat
 */
public class ChatAction extends ActionSupport implements SessionAware {

    // ==================== Attributs ====================
    private Channel channel;
    private String name;
    private List<Channel> listChannel;
    private List<Message> listMessage;

    private Map<String, Object> session;


    // ==================== Getters/Setters ====================
    public Channel getChannel() {
        return channel;
    }
    public String getName() {
        return name;
    }
    public void setName(String pName) {
        name = pName;
    }
    public void setChannel(Channel pChannel) {
        channel = pChannel;
    }
    public List<Channel> getListChannel() {
        return listChannel;
    }
    public List<Message> getListMessage() {
        return listMessage;
    }

    @Override
    public void setSession(Map<String, Object> pSession) {
        this.session = pSession;
    }


    // ==================== Méthodes ====================
    /**
     * Action permettant de sélectionner un Channel
     * @return input / success / error
     */
    public String doSelectChannel() {
        String vRetour = ActionSupport.INPUT;
        if (this.session.get("user") == null) {
            vRetour = "error-forbidden";
        } else if (StringUtils.isNotEmpty(name)) {
            try {
                channel = WebappHelper.getManagerFactory().getChatManager().getChannel(name);
            } catch (NotFoundException pE) {
                this.addActionError(pE.getMessage());
            }
            vRetour = ActionSupport.SUCCESS;
        } else {
            listChannel = WebappHelper.getManagerFactory().getChatManager().getListChannel();
        }
        return vRetour;
    }


    /**
     * Action permettant de créer un nouveau Channel
     * @return input / success
     */
    public String doNewChannel() throws TechnicalException {
        String vRetour = ActionSupport.INPUT;
        if (this.session.get("user") == null) {
            vRetour = "error-forbidden";
        } else if (StringUtils.isNotBlank(name)) {
            try {
                channel = new Channel(name);
                WebappHelper.getManagerFactory().getChatManager().addChannel(channel);
                vRetour = ActionSupport.SUCCESS;
            } catch (FunctionalException pE) {
                this.addActionError(pE.getMessage());
            }
        }
        return vRetour;
    }


    /**
     * Action affichant un channel
     * @return ERROR / success
     */
    public String doViewChannel() throws TechnicalException {
        String vRetour = ActionSupport.ERROR;
        if (this.session.get("user") == null) {
            vRetour = "error-forbidden";
        } else if (StringUtils.isNotEmpty(name)) {
            try {
                channel = WebappHelper.getManagerFactory().getChatManager().getChannel(name);
                listMessage = WebappHelper.getManagerFactory().getChatManager().getListNewMessage(channel, null);
                vRetour = ActionSupport.SUCCESS;
            } catch (NotFoundException pE) {
                this.addActionError(pE.getMessage());
            }
        } else {
            this.addActionError("Channel non précisé !");
        }
        return vRetour;
    }
}
