package org.example.palabres.webapp.action;

import java.util.Map;
import javax.servlet.http.HttpServletRequest;

import org.apache.commons.lang3.StringUtils;
import org.apache.struts2.interceptor.ServletRequestAware;
import org.apache.struts2.interceptor.SessionAware;
import com.opensymphony.xwork2.ActionSupport;

import org.example.palabres.model.bean.utilisateur.Utilisateur;
import org.example.palabres.model.exception.FunctionalException;
import org.example.palabres.webapp.WebappHelper;


/**
 * Action de gestion de la connexion/déconnexion d'un utilisateur
 */
public class LoginAction extends ActionSupport implements SessionAware, ServletRequestAware {


    // ==================== Attributs ====================
    // ----- Paramètres en entrée
    private String pseudo;

    // ----- Eléments Struts
    private Map<String, Object> session;
    private HttpServletRequest servletRequest;


    // ==================== Getters/Setters ====================
    public String getPseudo() {
        return pseudo;
    }
    public void setPseudo(String pPseudo) {
        pseudo = pPseudo;
    }

    @Override
    public void setSession(Map<String, Object> pSession) {
        this.session = pSession;
    }
    @Override
    public void setServletRequest(HttpServletRequest pRequest) {
        this.servletRequest = pRequest;
    }


    // ==================== Méthodes ====================
    /**
     * Action permettant la connexion d'un utilisateur
     * @return input / success
     */
    public String doLogin() {
        String vResult = ActionSupport.INPUT;
        if (!StringUtils.isAllEmpty(pseudo)) {
            try {
                // Ajout de l'utilisateur dans le business
                Utilisateur vUtilisateur = new Utilisateur(pseudo);
                WebappHelper.getManagerFactory().getUtilisateurManager().addUtilisateur(vUtilisateur);

                // Ajout de l'utilisateur en session
                this.session.put("user", vUtilisateur);

                vResult = ActionSupport.SUCCESS;
            } catch (FunctionalException pEx) {
                this.addActionError("Pseudo invalide ou existant !");
            }
        }
        return vResult;
    }


    /**
     * Action de déconnexion d'un utilisateur
     * @return success
     */
    public String doLogout() {
        // Suppression de l'utilisateur
        Object vUser = this.session.get("user");
        if (vUser instanceof Utilisateur) {
            WebappHelper.getManagerFactory().getUtilisateurManager().deleteUtilisateur((Utilisateur) vUser);
        }

        // Invalidation de la session
        this.servletRequest.getSession().invalidate();

        return ActionSupport.SUCCESS;
    }
}
